# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .match_quality import MatchQuality
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class MatchExplanation(UniversalBaseModel):
    matched: typing.Optional[str] = None
    uploaded: typing.Optional[str] = None
    name_custom_tf_idf_score: typing.Optional[float] = None
    high_quality_match_name: typing.Optional[bool] = None
    is_deletion_recommended: typing.Optional[bool] = None
    n_common_term_matches: typing.Optional[int] = None
    n_uncommon_term_matches: typing.Optional[int] = None
    match_quality: typing.Optional[MatchQuality] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
