# This file was auto-generated by Fern from our API Definition.

import typing

Attributes = typing.Union[
    typing.Literal[
        "person_status",
        "country",
        "address",
        "additional_information",
        "company_type",
        "position",
        "weak_identifier",
        "finances",
        "shares",
        "generic",
        "measurement",
        "status",
        "date_of_birth",
        "name",
        "financials",
        "gender",
        "translated_name",
        "risk_intelligence",
        "monetary_value",
        "identifier",
        "contact",
        "business_purpose",
    ],
    typing.Any,
]
