# This file was auto-generated by Fern from our API Definition.

from .bad_gateway import BadGateway
from .bad_request import BadRequest
from .connection_error import ConnectionError
from .internal_server_error import InternalServerError
from .method_not_allowed import MethodNotAllowed
from .not_acceptable import NotAcceptable
from .not_found import NotFound
from .rate_limit_exceeded import RateLimitExceeded
from .unauthorized import Unauthorized

__all__ = [
    "BadGateway",
    "BadRequest",
    "ConnectionError",
    "InternalServerError",
    "MethodNotAllowed",
    "NotAcceptable",
    "NotFound",
    "RateLimitExceeded",
    "Unauthorized",
]
