# This file was auto-generated by Fern from our API Definition.

import typing

MonetaryValueContext = typing.Union[
    typing.Literal["cost_insurance_and_freight", "free_on_board", "assessed_value"], typing.Any
]
