# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...shared_types.types.entity_details import EntityDetails
from ...shared_types.types.entity_relationships import EntityRelationships
from ...shared_types.types.relationship_data import RelationshipData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic
from ...core.pydantic_utilities import update_forward_refs


class EntitySummaryResponse(EntityDetails):
    """
    OK

    Examples
    --------
    from sayari.base_types import QualifiedCount
    from sayari.entity import EntitySummaryResponse
    from sayari.generated_types import (
        AddressData,
        AddressInfo,
        AddressProperties,
        AttributeDetails,
        BusinessPurposeData,
        BusinessPurposeInfo,
        BusinessPurposeProperties,
        CompanyTypeData,
        CompanyTypeInfo,
        CompanyTypeProperties,
        CountryData,
        CountryInfo,
        CountryProperties,
        IdentifierData,
        IdentifierInfo,
        IdentifierProperties,
        NameData,
        NameInfo,
        NameProperties,
        StatusData,
        StatusInfo,
        StatusProperties,
    )
    from sayari.shared_types import (
        Identifier,
        PossiblySameAs,
        PossiblySameAsData,
        PsaEntity,
        RecordDetails,
        ReferencedBy,
        ReferencedByData,
        RiskData,
        SourceCountInfo,
        Status,
    )

    EntitySummaryResponse(
        id="mGq1lpuqKssNWTjIokuPeA",
        label="VICTORIA BECKHAM LIMITED",
        degree=67,
        entity_url="/entity/mGq1lpuqKssNWTjIokuPeA",
        pep=False,
        psa_id="695785012897",
        psa_count=3,
        sanctioned=False,
        closed=False,
        company_type="Stock Corporation - Out of State - Stock",
        registration_date="Incorporated 2008-02-28",
        latest_status=Status(
            status="active",
            date="2023-08-29",
        ),
        trade_count={"sent": 41, "received": 0},
        type="company",
        identifiers=[
            Identifier(
                value="06517802",
                type="uk_company_number",
                label="Uk Company Number",
            ),
            Identifier(
                value="6517802",
                type="unknown",
                label="Unknown",
            ),
            Identifier(
                value="04781466",
                type="ca_corporate_id_num",
                label="Ca Corporate Id Num",
            ),
        ],
        addresses=[
            "202 HAMMERSMITH ROAD , LONDON , , UNITED KINGDOM , W6 7DN , GB",
            "Unit 33, Ransomes Dock Business Centre, 35-37 Parkgate Road, London SW11 4NP",
            "SAUNDERS BUILDING, 202 HAMMERSMITH ROAD, HAMMERSMITH, LONDON",
        ],
        countries=["GBR", "USA"],
        relationship_count={
            "linked_to": 3,
            "has_officer": 2,
            "shareholder_of": 1,
            "has_shareholder": 2,
            "has_registered_agent": 5,
            "shipper_of": 41,
            "has_director": 11,
            "owner_of": 3,
            "has_founder": 1,
            "ships_to": 1,
        },
        source_count={
            "2b618f1996252fe537a6d998ae14c9b2": SourceCountInfo(
                count=1,
                label="UK Corporate Registry Confirmation Statements",
            ),
            "2b788dbdf9194ed5a5c309386a6516b1": SourceCountInfo(
                count=28,
                label="UK HM Revenue & Customs Traders Database",
            ),
            "a447a7b622c4ead6e1caf94983dc2337": SourceCountInfo(
                count=6,
                label="USA California Secretary of State",
            ),
            "ecdfb3f2ecc8c3797e77d5795a8066ef": SourceCountInfo(
                count=35,
                label="UK Corporate Registry",
            ),
            "e5de7b52cc88ef4cd1a10e201bdf46ee": SourceCountInfo(
                count=41,
                label="Vietnam Imports & Exports (January 2023 - Present)",
            ),
            "2a4fe9a14e332c8f9ded1f8a457c2b89": SourceCountInfo(
                count=36,
                label="UK Land Commercial and Corporate Ownership Data (CCOD)",
            ),
            "4ea8bac1bed868e1510ffd21842e9551": SourceCountInfo(
                count=69,
                label="UK Persons with Significant Control",
            ),
        },
        risk={
            "basel_aml": RiskData(
                value=4.63,
                metadata={"country": ["USA"]},
                level="relevant",
            ),
            "cpi_score": RiskData(
                value=67.0,
                metadata={"country": ["USA"]},
                level="relevant",
            ),
        },
        user_attribute_count={},
        user_record_count=0,
        user_related_entities_count=0,
        user_relationship_count={},
        related_entities_count=67,
        attribute_count={
            "company_type": 2,
            "name": 2,
            "business_purpose": 4,
            "identifier": 3,
            "additional_information": 106,
            "country": 8,
            "status": 5,
            "address": 7,
        },
        reference_id="ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000:4a34442eccf1622995130b194a5d50e7",
        attributes=AttributeDetails(
            name=NameInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=2,
                    qualifier="eq",
                ),
                data=[
                    NameData(
                        properties=NameProperties(
                            value="BECKHAM VENTURES LIMITED",
                            context="alias",
                            to_date="2014-09-03",
                        ),
                        record=[
                            "2a4fe9a14e332c8f9ded1f8a457c2b89/NGL944625/1560779151522"
                        ],
                        record_count=30,
                    ),
                    NameData(
                        properties=NameProperties(
                            value="VICTORIA BECKHAM LIMITED",
                            context="primary",
                        ),
                        record=[
                            "ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000"
                        ],
                        record_count=157,
                    ),
                ],
            ),
            address=AddressInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=7,
                    qualifier="eq",
                ),
                data=[
                    AddressData(
                        properties=AddressProperties(
                            value="202 HAMMERSMITH ROAD UNITED KINGDOM",
                            house_number="202",
                            road="Hammersmith Road",
                            country="United Kingdom",
                            x=-0.22579,
                            y=51.49291,
                            precision_code="G3",
                            normalized="202 HAMMERSMITH KINGDOM RD UNITED",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1678752000000"
                        ],
                        record_count=5,
                    ),
                    AddressData(
                        properties=AddressProperties(
                            value="Unit 33, Ransomes Dock Business Centre, 35-37 Parkgate Road, London SW11 4NP",
                            house="Ransomes Dock Business Centre",
                            house_number="35-37",
                            unit="Unit 33",
                            road="Parkgate Road",
                            city="London",
                            postcode="Sw11 4np",
                            x=-0.16859,
                            y=51.47943,
                            precision_code="S8HPNTSCZA",
                            normalized="33 35 37 4NP BUSINESS CTR DOCK LONDON PARKGATE RANSOMES RD SW11 UNIT",
                        ),
                        record=[
                            "2a4fe9a14e332c8f9ded1f8a457c2b89/BGL137643/1560779151522"
                        ],
                        record_count=36,
                    ),
                    AddressData(
                        properties=AddressProperties(
                            value="202 HAMMERSMITH ROAD BRITISH ISLES",
                            house_number="202",
                            road="Hammersmith Road British Isles",
                            normalized="202 BRITISH HAMMERSMITH ISLE RD",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=1,
                    ),
                    AddressData(
                        properties=AddressProperties(
                            value="SAUNDERS BUILDING, 202 HAMMERSMITH ROAD, HAMMERSMITH, LONDON",
                            house="Saunders Building",
                            house_number="202",
                            road="Hammersmith Road",
                            suburb="Hammersmith",
                            city="London",
                            postcode="W6 7DN",
                            x=-0.22207,
                            y=51.49323,
                            precision_code="S8HPNTSC-A",
                            normalized="202 BUILDING HAMMERSMITH HAMMERSMITH LONDON RD SAUNDERS",
                        ),
                        record=[
                            "2b788dbdf9194ed5a5c309386a6516b1/213bcb98d1409787c3b3f668794fd233/1672444800000"
                        ],
                        record_count=28,
                    ),
                    AddressData(
                        properties=AddressProperties(
                            value="Ransome's Dock, 35-37 Parkgate Road, London, SW11 4NP",
                            house="Ransome's Dock",
                            house_number="35-37",
                            road="Parkgate Road",
                            city="London",
                            postcode="SW11 4NP",
                            x=-0.16784,
                            y=51.47898,
                            precision_code="S8HPNTSC-A",
                            normalized="35 37 4NP DOCK LONDON PARKGATE RANSOMES RD SW11",
                        ),
                        record=[
                            "4ea8bac1bed868e1510ffd21842e9551/08661308/1560176240192"
                        ],
                        record_count=15,
                    ),
                    AddressData(
                        properties=AddressProperties(
                            value="202 HAMMERSMITH ROAD , LONDON , , UNITED KINGDOM , W6 7DN , GB",
                            house_number="202",
                            road="Hammersmith Road",
                            city="London",
                            postcode="W6 7dn",
                            country="Gb",
                            x=-0.22207,
                            y=51.49323,
                            precision_code="S8HPNTSCZA",
                            normalized="202 7DN GB HAMMERSMITH KINGDOM LONDON RD UNITED W6",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=59,
                    ),
                    AddressData(
                        properties=AddressProperties(
                            value="Hammersmith Road, London, W6 7DN",
                            road="Hammersmith Road",
                            city="London",
                            postcode="W6 7DN",
                            x=-0.22138000000000002,
                            y=51.493080000000006,
                            precision_code="S4-PNTSCZA",
                            normalized="7DN HAMMERSMITH LONDON RD W6",
                        ),
                        record=[
                            "4ea8bac1bed868e1510ffd21842e9551/ef8cbb3fcc71d09f098f00728df231e8/1694476800000"
                        ],
                        record_count=8,
                    ),
                ],
            ),
            identifier=IdentifierInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=3,
                    qualifier="eq",
                ),
                data=[
                    IdentifierData(
                        properties=IdentifierProperties(
                            value="04781466",
                            type="ca_corporate_id_num",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    IdentifierData(
                        properties=IdentifierProperties(
                            value="06517802",
                            type="uk_company_number",
                        ),
                        record=[
                            "ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000"
                        ],
                        record_count=126,
                    ),
                    IdentifierData(
                        properties=IdentifierProperties(
                            value="6517802",
                            type="unknown",
                        ),
                        record=[
                            "4ea8bac1bed868e1510ffd21842e9551/08661308/1560176240192"
                        ],
                        record_count=15,
                    ),
                ],
            ),
            status=StatusInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=5,
                    qualifier="eq",
                ),
                data=[
                    StatusData(
                        properties=StatusProperties(
                            text="Good",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    StatusData(
                        properties=StatusProperties(
                            value="incorporated",
                            date="2008-02-28",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=18,
                    ),
                    StatusData(
                        properties=StatusProperties(
                            text="Good",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    StatusData(
                        properties=StatusProperties(
                            value="active",
                            text="Active",
                            date="2023-08-29",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=24,
                    ),
                    StatusData(
                        properties=StatusProperties(
                            value="registered",
                            text="INITIAL_FILING_DATE",
                            date="2021-08-24",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                ],
            ),
            company_type=CompanyTypeInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=2,
                    qualifier="eq",
                ),
                data=[
                    CompanyTypeData(
                        properties=CompanyTypeProperties(
                            value="Stock Corporation - Out of State - Stock",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    CompanyTypeData(
                        properties=CompanyTypeProperties(
                            value="Private Limited Company",
                        ),
                        record=[
                            "4ea8bac1bed868e1510ffd21842e9551/08661308/1560176240192"
                        ],
                        record_count=41,
                    ),
                ],
            ),
            business_purpose=BusinessPurposeInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=4,
                    qualifier="eq",
                ),
                data=[
                    BusinessPurposeData(
                        properties=BusinessPurposeProperties(
                            value="Other amusement and recreation activities n.e.c.",
                            code="9329",
                            standard="ISIC4",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=18,
                    ),
                    BusinessPurposeData(
                        properties=BusinessPurposeProperties(
                            value="LADIES FASHION",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    BusinessPurposeData(
                        properties=BusinessPurposeProperties(
                            value="Other amusement and recreation activities n.e.c.",
                            code="93290",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=18,
                    ),
                    BusinessPurposeData(
                        properties=BusinessPurposeProperties(
                            value="Other amusement and recreation activities",
                            code="93.29",
                            standard="NACE2",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=18,
                    ),
                ],
            ),
            country=CountryInfo(
                offset=0,
                limit=50,
                next=false,
                size=QualifiedCount(
                    count=8,
                    qualifier="eq",
                ),
                data=[
                    CountryData(
                        properties=CountryProperties(
                            value="GBR",
                            context="address",
                        ),
                        record=[
                            "9aef3a56aa0ea25404b498dbd8bb447f/06517802/1579014552807"
                        ],
                        record_count=23,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="GBR",
                            context="activity_in",
                        ),
                        record=[
                            "ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000"
                        ],
                        record_count=82,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="GBR",
                            context="domicile",
                        ),
                        record=[
                            "4ea8bac1bed868e1510ffd21842e9551/ef8cbb3fcc71d09f098f00728df231e8/1694476800000"
                        ],
                        record_count=8,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="USA",
                            context="domicile",
                            state="US-DE",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="GBR",
                            context="address",
                        ),
                        record=[
                            "e5de7b52cc88ef4cd1a10e201bdf46ee/{4DC73DBC-FC75-42F3-8A4AAED3254239E1}/1690329600000"
                        ],
                        record_count=41,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="USA",
                            context="activity_in",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="GBR",
                            context="mentioned_in",
                        ),
                        record=[
                            "ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000"
                        ],
                        record_count=141,
                    ),
                    CountryData(
                        properties=CountryProperties(
                            value="USA",
                            context="mentioned_in",
                        ),
                        record=[
                            "9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000"
                        ],
                        record_count=6,
                    ),
                ],
            ),
        ),
        possibly_same_as=PossiblySameAs(
            limit=50,
            size=QualifiedCount(
                count=3,
                qualifier="eq",
            ),
            offset=0,
            next=false,
            data=[
                PossiblySameAsData(
                    entity=PsaEntity(
                        id="NGUTEUTI4YZ6R5d56vgNIw",
                        label="BECKHAM VENTURES INC.",
                        degree=3,
                        entity_url="/entity/NGUTEUTI4YZ6R5d56vgNIw",
                        pep=False,
                        psa_id="695785012897",
                        psa_count=3,
                        sanctioned=False,
                        closed=False,
                        company_type="FOREIGN BUSINESS CORPORATION",
                        registration_date=" 2013-01-16",
                        latest_status=Status(
                            status="active",
                            date="2013-01-16",
                        ),
                        trade_count={"sent": 0, "received": 0},
                        type="company",
                        identifiers=[
                            Identifier(
                                value="4346762",
                                type="usa_ny_dos_id",
                                label="Usa Ny Dos Id",
                            )
                        ],
                        addresses=[
                            "99 WASHINGTON AVE., SUITE 805A, ALBANY, NY, 12201",
                            "511 WEST 25TH STREET, SUITE # 701/7TH FLOOR, NEW YORK, NEW YORK, 10001",
                            "80 STATE STREET, ALBANY, NEW YORK, 12207-2543",
                        ],
                        countries=["USA"],
                        relationship_count={
                            "has_officer": 1,
                            "has_registered_agent": 2,
                            "linked_to": 2,
                        },
                        source_count={
                            "b4d06d4b77f51fab3c77c9653aabdda4": SourceCountInfo(
                                count=8,
                                label="USA New York Corporate Registry (Active Entities)",
                            )
                        },
                        risk={
                            "basel_aml": RiskData(
                                value=4.63,
                                metadata={"country": ["USA"]},
                                level="relevant",
                            ),
                            "cpi_score": RiskData(
                                value=67.0,
                                metadata={"country": ["USA"]},
                                level="relevant",
                            ),
                        },
                        user_attribute_count={},
                        user_record_count=0,
                        user_related_entities_count=0,
                        user_relationship_count={},
                        related_entities_count=3,
                        attribute_count={
                            "company_type": 1,
                            "name": 1,
                            "identifier": 1,
                            "country": 3,
                            "status": 1,
                            "address": 3,
                        },
                        reference_id="b4d06d4b77f51fab3c77c9653aabdda4/a80e7f4c-c219-437b-9941-32d89ea5885a/1560542045043:15d813b260619393762864f22d3c5b2d",
                    ),
                    matches={},
                ),
                PossiblySameAsData(
                    entity=PsaEntity(
                        id="Fv6k3Wmcq8fKdLoDLQM_Xw",
                        label="BECKHAM VENTURES INC.",
                        degree=1,
                        entity_url="/entity/Fv6k3Wmcq8fKdLoDLQM_Xw",
                        pep=False,
                        psa_id="695785012897",
                        psa_count=3,
                        sanctioned=False,
                        closed=False,
                        company_type="GENERAL",
                        registration_date="Incorporated 2013-01-14",
                        trade_count={"sent": 0, "received": 0},
                        type="company",
                        identifiers=[
                            Identifier(
                                value="5273939",
                                type="usa_de_file_number",
                                label="Usa De File Number",
                            )
                        ],
                        addresses=[],
                        countries=["USA"],
                        relationship_count={"has_registered_agent": 1},
                        source_count={
                            "29ec06417b900ffe3fedd42d02b1b6d7": SourceCountInfo(
                                count=1,
                                label="USA Delaware Secretary of State",
                            )
                        },
                        risk={
                            "basel_aml": RiskData(
                                value=4.63,
                                metadata={"country": ["USA"]},
                                level="relevant",
                            ),
                            "cpi_score": RiskData(
                                value=67.0,
                                metadata={"country": ["USA"]},
                                level="relevant",
                            ),
                        },
                        user_attribute_count={},
                        user_record_count=0,
                        user_related_entities_count=0,
                        user_relationship_count={},
                        related_entities_count=1,
                        attribute_count={
                            "company_type": 1,
                            "name": 1,
                            "identifier": 1,
                            "country": 2,
                            "status": 1,
                        },
                        reference_id="985b4533cd1cb2db1d736dd31f8e34c9/January 2013.pdf/1643737587282:f1b8f7a9ed23af356dcd37ce6c3ea059",
                    ),
                    matches={},
                ),
                PossiblySameAsData(
                    entity=PsaEntity(
                        id="EINtsur0kjyyS7w7ObvhBA",
                        label="VICTORIA BECKHAM LIMITED",
                        degree=1,
                        entity_url="/entity/EINtsur0kjyyS7w7ObvhBA",
                        pep=False,
                        psa_id="695785012897",
                        psa_count=3,
                        sanctioned=False,
                        closed=False,
                        trade_count={"sent": 0, "received": 0},
                        type="company",
                        identifiers=[],
                        addresses=[
                            "ST CHRISTOPHER'S PLACE   NUM. EXT. 4 GEE'S COURT NUM. INT. C/O LEE & THOMPSON LLP"
                        ],
                        countries=["GBR", "MEX"],
                        relationship_count={"owner_of": 1},
                        source_count={
                            "b9d809b02049993ba8dc2e4c5f7cceca": SourceCountInfo(
                                count=16,
                                label="Mexico Industrial Property Trademark Registry (MARCIA)",
                            )
                        },
                        risk={
                            "basel_aml": RiskData(
                                value=3.99,
                                metadata={"country": ["GBR"]},
                                level="relevant",
                            ),
                            "cpi_score": RiskData(
                                value=78.0,
                                metadata={"country": ["GBR"]},
                                level="relevant",
                            ),
                        },
                        user_attribute_count={},
                        user_record_count=0,
                        user_related_entities_count=0,
                        user_relationship_count={},
                        related_entities_count=1,
                        attribute_count={"name": 1, "address": 1, "country": 2},
                        reference_id="b9d809b02049993ba8dc2e4c5f7cceca/RM201902324751/1590507065822:5289443ba2cdf59a7c656b77584a49fc",
                    ),
                    matches={},
                ),
            ],
        ),
        referenced_by=ReferencedBy(
            limit=50,
            size=QualifiedCount(
                count=216,
                qualifier="eq",
            ),
            offset=0,
            next=true,
            data=[
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{D634B9B1-39E2-4273-8F35AE81130E18D7}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BD634B9B1-39E2-4273-8F35AE81130E18D7%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{BFC9056E-9711-49CC-AC6B4F3D19809ABC}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BBFC9056E-9711-49CC-AC6B4F3D19809ABC%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{B6BE3A73-D320-44B8-875BC573F54210FD}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BB6BE3A73-D320-44B8-875BC573F54210FD%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{8A7A08E2-123B-4FAE-94BF66C6F3BA6BEA}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B8A7A08E2-123B-4FAE-94BF66C6F3BA6BEA%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{5A8089A5-891D-43C4-BEA50DCB4D32401E}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B5A8089A5-891D-43C4-BEA50DCB4D32401E%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{596910C7-D648-4A2C-BFFA77F966A8962D}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B596910C7-D648-4A2C-BFFA77F966A8962D%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{4756305B-2033-40A4-9BD867B6EFA8C9B2}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B4756305B-2033-40A4-9BD867B6EFA8C9B2%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{32A66456-B070-4F55-8D117D740BED2ECF}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B32A66456-B070-4F55-8D117D740BED2ECF%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{22B19094-CEDF-4100-BDC2CA091A4FF5A9}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B22B19094-CEDF-4100-BDC2CA091A4FF5A9%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{1AD11C10-D7D6-4504-B5CC9E6177795A0E}/1704240000000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2024-01-03",
                        acquisition_date="2024-01-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B1AD11C10-D7D6-4504-B5CC9E6177795A0E%7D%2F1704240000000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{F71CAC67-4F08-48D5-A15EFCA682205705}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BF71CAC67-4F08-48D5-A15EFCA682205705%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{F450EB48-AF31-44EC-92D47886A3CEB625}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BF450EB48-AF31-44EC-92D47886A3CEB625%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{B7F7DA58-63AF-461B-B708FC2C7514355F}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BB7F7DA58-63AF-461B-B708FC2C7514355F%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{968CEF6C-F2CA-4298-9D33475268924C3A}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B968CEF6C-F2CA-4298-9D33475268924C3A%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{952E6357-B36F-4802-A5B3E84AAA42CE8E}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B952E6357-B36F-4802-A5B3E84AAA42CE8E%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{72007C6B-740B-451A-BD4C61114679B8EF}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B72007C6B-740B-451A-BD4C61114679B8EF%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{70EEEDF9-BD5C-4770-8EF76D52CB6DC0EE}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B70EEEDF9-BD5C-4770-8EF76D52CB6DC0EE%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{5EBBA4A9-153C-4243-86675561CE321275}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B5EBBA4A9-153C-4243-86675561CE321275%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{4D2F724B-B98C-4D5D-A98E8ADC8C2C46FF}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B4D2F724B-B98C-4D5D-A98E8ADC8C2C46FF%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{4B4E435B-3975-4345-8177CF444DCF7324}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B4B4E435B-3975-4345-8177CF444DCF7324%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{44A3E2B5-901D-4360-9DEB8EF35019ED15}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B44A3E2B5-901D-4360-9DEB8EF35019ED15%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{428CEE8F-F33B-4598-97CE9C6CCDFBF8DD}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B428CEE8F-F33B-4598-97CE9C6CCDFBF8DD%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{2F726716-BED1-4AE0-A1A616900B61F1E3}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B2F726716-BED1-4AE0-A1A616900B61F1E3%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{247A2589-CDBF-47CD-9067FB972808C874}/1698969600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-11-03",
                        acquisition_date="2023-11-03",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B247A2589-CDBF-47CD-9067FB972808C874%7D%2F1698969600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{F5C41EC6-EE88-4121-BCAD5AA81E93C00B}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BF5C41EC6-EE88-4121-BCAD5AA81E93C00B%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{D6757BC6-2BCF-4D87-A3F53F99025121E8}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BD6757BC6-2BCF-4D87-A3F53F99025121E8%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{D0885822-D92D-42BE-8CDB4FA889F1E2B4}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BD0885822-D92D-42BE-8CDB4FA889F1E2B4%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{C117BC85-81E6-40D1-A61DF66FD04694AF}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BC117BC85-81E6-40D1-A61DF66FD04694AF%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{AD48A141-FA80-4F09-B97229C9DBA3367D}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BAD48A141-FA80-4F09-B97229C9DBA3367D%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{A98A356D-E3EE-427D-9FE5E8481C2D5890}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7BA98A356D-E3EE-427D-9FE5E8481C2D5890%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{988597F4-E258-4342-983E7D7B38C539CB}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B988597F4-E258-4342-983E7D7B38C539CB%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{82552661-B818-48A7-BE6962B7C6E89DD2}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B82552661-B818-48A7-BE6962B7C6E89DD2%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{575FEE26-922F-401D-AE815061380066BB}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B575FEE26-922F-401D-AE815061380066BB%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{4DC73DBC-FC75-42F3-8A4AAED3254239E1}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B4DC73DBC-FC75-42F3-8A4AAED3254239E1%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{3E4B4DE7-CFF4-43B2-831C9CE5D2B21D94}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B3E4B4DE7-CFF4-43B2-831C9CE5D2B21D94%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{3B5D2BEC-8F38-4DC0-86C2C4C20A37176E}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B3B5D2BEC-8F38-4DC0-86C2C4C20A37176E%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{3059B414-F15D-4D7C-A85D09A31FA0D600}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B3059B414-F15D-4D7C-A85D09A31FA0D600%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{2D68218F-1C6A-4809-98AA6B06BB09EF74}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B2D68218F-1C6A-4809-98AA6B06BB09EF74%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{24036F32-7BD0-4E22-8DB93CAFDD940917}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B24036F32-7BD0-4E22-8DB93CAFDD940917%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{186A7E83-88B9-4D9D-B9B7B5E2E41FF046}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B186A7E83-88B9-4D9D-B9B7B5E2E41FF046%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="e5de7b52cc88ef4cd1a10e201bdf46ee/{1263162D-9752-4A73-86224B2242C245F5}/1690329600000",
                        label="Trade Record from Vietnam Imports & Exports (January 2023 - Present)",
                        source="e5de7b52cc88ef4cd1a10e201bdf46ee",
                        publication_date="2023-07-26",
                        acquisition_date="2023-07-26",
                        references_count=3,
                        record_url="/record/e5de7b52cc88ef4cd1a10e201bdf46ee%2F%7B1263162D-9752-4A73-86224B2242C245F5%7D%2F1690329600000",
                    ),
                    type="mentions",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="9139b58de1bdb0157a1a1e54e56df6d3/4781466/1709769600000",
                        label="Company Record from USA California Secretary of State",
                        source="a447a7b622c4ead6e1caf94983dc2337",
                        publication_date="2024-03-07",
                        acquisition_date="2024-03-07",
                        references_count=5,
                        record_url="/record/9139b58de1bdb0157a1a1e54e56df6d3%2F4781466%2F1709769600000",
                        source_url="https://bizfileonline.sos.ca.gov/search/business",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="9139b58de1bdb0157a1a1e54e56df6d3/4781466/1701648000000",
                        label="Company Record from USA California Secretary of State",
                        source="a447a7b622c4ead6e1caf94983dc2337",
                        publication_date="2023-12-04",
                        acquisition_date="2023-12-04",
                        references_count=4,
                        record_url="/record/9139b58de1bdb0157a1a1e54e56df6d3%2F4781466%2F1701648000000",
                        source_url="https://bizfileonline.sos.ca.gov/search/business",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="9139b58de1bdb0157a1a1e54e56df6d3/4781466/1693872000000",
                        label="Company Record from USA California Secretary of State",
                        source="a447a7b622c4ead6e1caf94983dc2337",
                        publication_date="2023-09-05",
                        acquisition_date="2023-09-05",
                        references_count=4,
                        record_url="/record/9139b58de1bdb0157a1a1e54e56df6d3%2F4781466%2F1693872000000",
                        source_url="https://bizfileonline.sos.ca.gov/search/business",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="9139b58de1bdb0157a1a1e54e56df6d3/4781466/1685664000000",
                        label="Company Record from USA California Secretary of State",
                        source="a447a7b622c4ead6e1caf94983dc2337",
                        publication_date="2023-06-02",
                        acquisition_date="2023-06-02",
                        references_count=4,
                        record_url="/record/9139b58de1bdb0157a1a1e54e56df6d3%2F4781466%2F1685664000000",
                        source_url="https://bizfileonline.sos.ca.gov/search/business",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="9139b58de1bdb0157a1a1e54e56df6d3/4781466/1678752000000",
                        label="Company Record from USA California Secretary of State",
                        source="a447a7b622c4ead6e1caf94983dc2337",
                        publication_date="2023-03-14",
                        acquisition_date="2023-03-14",
                        references_count=4,
                        record_url="/record/9139b58de1bdb0157a1a1e54e56df6d3%2F4781466%2F1678752000000",
                        source_url="https://bizfileonline.sos.ca.gov/search/business",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="9139b58de1bdb0157a1a1e54e56df6d3/4781466/1649116800000",
                        label="Company Record from USA California Secretary of State",
                        source="a447a7b622c4ead6e1caf94983dc2337",
                        publication_date="2022-04-05",
                        acquisition_date="2022-04-05",
                        references_count=4,
                        record_url="/record/9139b58de1bdb0157a1a1e54e56df6d3%2F4781466%2F1649116800000",
                        source_url="https://bizfileonline.sos.ca.gov/search/business",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1706054400000",
                        label="Company Record from UK Corporate Registry",
                        source="ecdfb3f2ecc8c3797e77d5795a8066ef",
                        publication_date="2024-01-24",
                        acquisition_date="2024-01-24",
                        references_count=16,
                        record_url="/record/ecdfb3f2ecc8c3797e77d5795a8066ef%2F06517802%2F1706054400000",
                        source_url="https://beta.companieshouse.gov.uk/company/",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1680566400000",
                        label="Company Record from UK Corporate Registry",
                        source="ecdfb3f2ecc8c3797e77d5795a8066ef",
                        publication_date="2023-04-04",
                        acquisition_date="2023-04-04",
                        references_count=9,
                        record_url="/record/ecdfb3f2ecc8c3797e77d5795a8066ef%2F06517802%2F1680566400000",
                        source_url="https://beta.companieshouse.gov.uk/company/",
                    ),
                    type="about",
                ),
                ReferencedByData(
                    record=RecordDetails(
                        id="ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1677542400000",
                        label="Company Record from UK Corporate Registry",
                        source="ecdfb3f2ecc8c3797e77d5795a8066ef",
                        publication_date="2023-02-28",
                        acquisition_date="2023-02-28",
                        references_count=9,
                        record_url="/record/ecdfb3f2ecc8c3797e77d5795a8066ef%2F06517802%2F1677542400000",
                        source_url="https://beta.companieshouse.gov.uk/company/",
                    ),
                    type="about",
                ),
            ],
        ),
    )
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EntityDetails, EntitySummaryResponse=EntitySummaryResponse)
update_forward_refs(EntityRelationships, EntitySummaryResponse=EntitySummaryResponse)
update_forward_refs(RelationshipData, EntitySummaryResponse=EntitySummaryResponse)
