# This file was auto-generated by Fern from our API Definition.

import typing

NameContext = typing.Union[
    typing.Literal["primary", "given", "family", "alias", "machine_translation", "transliteration", "trade_name"],
    typing.Any,
]
