# This file was auto-generated by Fern from our API Definition.

import enum


class SayariEnvironment(enum.Enum):
    PRODUCTION = "https://api.sayari.com"
    DEV = "https://api.internal.sayari.com"
