# This file was auto-generated by Fern from our API Definition.

import typing

Relationships = typing.Union[
    typing.Literal[
        "lawyer_of",
        "has_lawyer",
        "founder_of",
        "has_founder",
        "legal_predecessor_of",
        "has_legal_predecessor",
        "lawyer_in",
        "shipper_of",
        "shipped_by",
        "associate_of",
        "has_associate",
        "judicial_representative_of",
        "has_judicial_representative",
        "sole_proprietor_of",
        "has_sole_proprietor",
        "shareholder_of",
        "has_shareholder",
        "subsidiary_of",
        "has_subsidiary",
        "executive_of",
        "has_executive",
        "liquidator_of",
        "has_liquidator",
        "registered_agent_of",
        "has_registered_agent",
        "auditor_of",
        "has_auditor",
        "legal_representative_of",
        "has_legal_representative",
        "judidical_representative_of",
        "employee_of",
        "has_employee",
        "officer_of",
        "has_officer",
        "generic",
        "member_of_the_board_of",
        "has_member_of_the_board",
        "notify_party_of",
        "has_notify_party",
        "beneficial_owner_of",
        "has_beneficial_owner",
        "client_of",
        "has_client",
        "partner_of",
        "has_partner",
        "issuer_of",
        "has_issuer",
        "branch_of",
        "has_branch",
        "secretary_of",
        "has_secretary",
        "party_to",
        "has_party",
        "legal_successor_of",
        "has_legal_successor",
        "receiver_of",
        "received_by",
        "owner_of",
        "has_owner",
        "linked_to",
        "supervisor_of",
        "has_supervisor",
        "manager_of",
        "has_manager",
        "family_of",
        "carrier_of",
        "has_carrier",
        "ships_to",
        "receives_from",
        "director_of",
        "has_director",
        "possibly_same_as",
    ],
    typing.Any,
]
